# Backend.AI Cloud Consolidated Service Terms of Use

## Article 1 General Provisions

### Section 1 (Purpose)

These Terms of Use (“Terms”) are provided for the purpose of setting forth the rights, obligations, and responsibilities and other necessary conditions between Lablup Inc. (the “Company”) and its users (“Members”) relating to the use of the Backend.AI Cloud Service (the “Service”) provided by the Company.

### Section 2 (Definition)

The following defined terms used herein shall have the following meanings ascribed to them, and any terms not defined herein shall have the meanings ascribed to them by law, our service policies, and general custom.

1. "Member" means a user that accepts these Terms and that enter into a service contract with the Company for the use of the Service.

2. “Site” means the following websites operated by the Company, where Members use a single ID and password to access and use the Services provided on such websites.

   - Sites (as of [date] 2019)

     - Company main homepage: https://lablup.com
     - Backend.AI Cloud: https://www.backend.ai

3. “Account" means a unique combination of letters, numbers, and/or special characters selected by a Member and provided by a Company for the purpose of the use of the Service.

4. "Password" means combination of letters, numbers, and/or special characters selected by a Member that is matched with the Member’s Account to verify the Member’s identity and to protect his/her rights and information.

5. "Account Data" means information provided to the Company by a Member, including his/her account, password, name, service use data and other information.

6. “Credit” means a unit that is used for the purpose of using the Service with 1 Credit being the equivalent of KRW 1.

7. “Cloud Service” means the service that provides telecommunication resources to users through hardware and software that does not belong to the user, which is installed on an external (cloud) server.

### Section 3 (Statement and Amendment of Terms)

1. These Terms are notified to Members either through posting on the Company homepage (https://lablup.com) and its service page (https://www.backend.ai) or through a linked screen, where any Member can confirm the Company’s name, location, name of representative, business registration number, contact information, etc.
2. The Company may amend these Terms at any time to comply with relevant laws and regulations.
3. If the Company amends these Terms, the Company shall notify Members of the amended terms, the reason for the amendment, and the effective date by posting the notice 7 days prior to the effective date of the amendment (30 days prior to the effective date in case of an unfavorable or major change) according to the methods set forth in Section 4.
4. If the Company amends the Terms, it will send Members notice of such amendment and confirm their agreement with the amended Terms. However, the Company may give notice that they will be deemed to have accepted the amended Terms unless they express their rejection by the effective date of the amended Terms, and if the Member does not express his/her intention to deny consent or withdraws as a Member by the effective date of the amended Terms, the Member shall be deemed to have agreed to all the contents set forth in the amended Terms.
5. The Company shall not apply the provisions of the amended Terms to Members that have not agreed to the amendment. In such case, the Company and the Member may terminate the service contract.
6. The amended Terms will, in principle, be effective from the effective date.

### Section 4 (Notice to Members)

1. If the Company wishes to send a notice to a Member, it will send the notice to the email provided by the Member at the time of his/her registration unless otherwise provided under these Terms. However, if notice through email is not practical, it may send the notice through text message, mail, or other means.
2. If the Company must send notices to all Members, the Company may substitute email notices with posting a notice on its homepage or its service page for a period of at least 7 days. However, this will not apply in the case of notices regarding adverse changes to the rights and obligations of Members.
3. Members are responsible for ensuring that all contact information (email, phone, mobile, etc.) are up to date for the purpose of receiving the Company’s notices. The Company will not be responsible for adverse events resulting from a Member’s failure to update his/her contact information.

## Article 2 Use of Service

### Section 5 (Member Registration and Service Contract)

1. Membership applicants enter into a service contract with the Company after agreeing to these Terms, filling out their member information form, and applying for membership.
2. At the time of the application, applicants expressly choose to agree to these Terms by selecting “I Agree” or making other explicit statements of their acceptance to these Terms.
3. The Company may require applicants to provide their real name and verify their identity, as well as other necessary information, and such process shall be done in accordance with relevant law.
4. The Company may designate the necessary terms of the Service: scope of use, time of availability for use, frequency of use, and fees, among others, and the Member may only use the Service according to such terms.
5. The information provided by the applicant during the application process must be true. Applicants providing false names or information or misusing another individual’s name have no claim to any rights under these Terms and the Company may cancel or terminate the service contract without any refunds.
6. Personal information provided by applicants will be protected according to relevant laws and the Privacy Policy.

### Section 6 (Application Acceptance and Limitations)

1. The Company will accept applicants that apply in compliance with Section 5 unless special circumstances apply.
2. The Company may reject any application or terminate any service contract under any of the following circumstances.
   1. The applicant does not use his/her real name or uses another person’s name for the application.
   2. The record shows that the applicant was subject to restrictions by the Company within the last 3 months due to the fault of the applicant.
   3. The applicant is applying for the purpose of engaging in illegal activity.
   4. The applicant that competes with the Service is applying with the intent to decrease the profits of the Company.
   5. The applicant was previously a Member that lost his/her membership status and the Company refuses his/her application.
   6. Other similar circumstances where the Company deems that it would be inappropriate or impractical to provide the Service to the applicant/Member.
3. The Company may postpone acceptance of an application under any of the following circumstances until such circumstance is resolved.
   1. Insufficient memory for the Service or the Company’s equipment does not have capacity.
   2. Technical difficulties.
   3. Other similar circumstances where the Company deems that it would be inappropriate or impractical to accept the application.
4. If the Company chooses to reject or postpone acceptance of an application, it will inform the applicant in accordance with Section 4.
5. If the Company accepts an applicant’s application, a valid service contract shall be deemed to have been entered into between the Company and the Member unless such would constitute a breach of these Terms or a violation of relevant law.

### Section 7 (ID and Password)

1. The Company will provide an Account (ID) and the Account will be in the form of the email address used by the Member.
2. The Company based on the Account Data has the sole discretion to determine whether the Member may use the Service and to manage its Members. The Company may change or request the Member to change its Account name and/or Password under any of the following circumstances.
   1. The Account name is offensive to others or is against public morals.
   2. The change is necessary for security reasons or for the provision of the Service.
   3. Other similar circumstances the Company deems necessary.
3. A Member must exercise due care of a good manager regarding the Account he/she created and only he/she should use such Account. The Member is solely responsible for any damages arising from his/her careless management of his/her Account Data or allowing third parties to use the Account.
4. The Member is responsible for the safekeeping of his/her password and can change his/her password at any time.
5. Any Member that becomes aware of any misuse or disclosure to third parties of Account Data shall immediately inform the Company and follow the Company’s instructions. The Company will not be liable for any damages resulting from a Member’s failure to inform the Company of any of the aforementioned events or his/her failure to follow the Company’s instructions.
6. The Member shall be solely responsible for any and all damages incurred by third parties that result from his/her failure to properly manage his/her Account and the Company shall have no liability with respect to such damages.

### Section 8 (Providing and Modifying Member Information)

1. In the event the Member must provide the Company with information pursuant to the Terms the Member must provide true and accurate information and will receive no protection for any false information provided.
2. A Member can access or modify his/her personal information at any time on the homepage or the service page. However, information required for Service maintenance, such as the Member’s real name and ID cannot be modified. As such, a Member that seeks to change his/her ID must terminate his/her Account and reapply. Upon withdrawing as a Member, the relevant Account will be permanently disabled and cannot be reactivated.
3. If there are any changes to the information provided to the Company by a Member, the Member must reflect such changes by modifying the information on the homepage or the service page. If the Member is unable to modify the information, he/she must inform the Company of such change.
4. The Member is solely responsible, and the Company shall not be liable for, any disadvantages to the Member resulting from any failure by the Member to modify the information or to inform the Company of changes to his/her information.

### Section 9 (Consolidated Membership)

1. A Member may use a single consolidated Account to utilize all the websites mentioned in Section 2.2.
2. The Company may require separate or additional registration procedures for the provision of certain services from certain sites and the terms of use, regulations and other policies (if any) shall prevail over these Terms with respect to the use of such services.
3. The Company may manage the Account (including personal information) of a Member or make improvements or changes to the Site or Service for the Member’s convenient use of the Site or the Service.
4. Upon a Member’s application and the Company’s acceptance thereof, the Company may add additional sites to Section 2.2, and these Terms shall apply to the extent such sites do not have a separate terms of use.

### Section 10 (Protection and Management of Personal Information)

1. The Company is committed to protecting its Members’ Account Data and other personal information according to relevant laws. Protection and use of personal information will be governed by relevant laws and regulations and the Company’s privacy policy.
2. For the Members’ secure use of the Services, the Company shall utilize a security system to protect personal information and financial information and announce and comply with its Privacy Policy. The Company will not disclose or provide Members’ personal information to any third parties unless required by law or otherwise stated in its Privacy Policy.
3. The Company shall not be held responsible for any personal or private information including any Account Data of the User that is leaked due to the Member’s fault.

### Section 11 (Service to Members)

A Member may receive the following Service from system provided by the Company.

1. A Member may receive cloud services to perform work related to the development and implementation of programming and machine learning models on a network without purchasing separate hardware or software.
2. A Member may receive cloud services for the retention, storage, and maintenance of data on a network without purchasing separate hardware or software.
3. Other services provided to Members developed by the Company or provided by other partner companies.
4. Technical support and other ancillary services with respect to paragraphs 1 through 3 above.

### Section 12 (Changes to the Service)

1. The Company may make changes to the Service as necessary for its operations or technology, in which event the Company shall give notice to the Member.
2. Despite the Company’s proper delivery of the notice to the Member regarding changes to the Service, if the Member does not accept receipt of the notice, the Company shall not be liable for any damages resulting therefrom.

### Section 13 (Intellectual Property)

1. All intellectual property rights relating to the Service shall remain with the Company.
2. All intellectual property rights in and to the results of development and other work product resulting from the Member’s use of the Service (“Work Product”) shall belong to the Member. The Member agrees that the Company may retain, store, manage, and process the Work Product in relation to the Service provided pursuant to these Terms, and grants the Company all rights necessary to take such actions.
3. The Member must use the Service within the scope of purpose and method authorized by the Company and shall not infringe the intellectual property rights of any third parties in breach of such restrictions. The Member shall be solely liable for any such infringements of third-party intellectual property rights and the Company shall bear no liability with respect to such infringements.

### Section 14 (Provision and Cancellation of the Service)

1. From the date the Company accepts a Member’s application for use, the Service will be made available to such member; however, if necessary, certain services may be made available from a certain time, in which case the Company will provide the Member with notice before or after it makes such a determination.
2. If necessary, the Company may provide certain services to only certain members and may divide the schedule for use of the Service to determine separate time periods in which different groups may use the Service according to their respective authorized scope. In such case, the Company shall post a notice on the homepage or the service page or provide notice separately to each Member before or after it makes such a determination.
3. The Company, in principle, will provide the Service all year round, 24 hours a day, and 7 days a week.
4. Notwithstanding paragraph 3, the Service may be suspended under any of the following circumstances and the Company shall have no obligation to provide any Service to the Members.
   1. When necessary for maintenance, replacement, regular inspection of information and communication facilities such as computers or modification of the Service.
   2. When necessary to respond to electronic infringement incidents such as hacking, communication accidents, abnormal service usage behavior of Members, and unexpected instability of the Service.
   3. Where applicable law prohibits the provision of the Service at specific times or by certain methods.
   4. In case normal Services cannot be provided due to natural disaster, national emergency, power outage, service equipment failure or congestion of Service.
   5. In case of management necessity such as spin-off, merger, transfer of business, closing of business, or deterioration of profitability of the Service.
5. In any of the circumstances set forth in paragraph 4, the Company will take efforts to notify Members on the homepage or the service page. Despite the Company delivering proper notice to Members, if a Member remains unaware of such contents, the Company shall not be liable for any damages incurred. If there are circumstances where it is impossible or impracticable for the Company to provide prior notice (e.g., emergency system maintenance, extension, or replacement; disk defects or system failure for reasons not attributable to willful misconduct or negligence of the system manager; impossibility of providing services due to circumstances of the telecommunications provider or other circumstances outside of the Company’s control) it shall provide notice as soon as possible after the end of such circumstances.
6. The Company shall not be liable for any failure to store or a loss of a Member’s data resulting from any of the circumstances set forth in paragraph 4 except in the case of willful misconduct or gross negligence of the Company.

### Section 15 (Suspension of Termination of the Service by the Company)

1. The Company may suspend the Service without prior notice in the event of a breach of these Terms by the Member or under any of the following circumstances.
   1. If the Member has not paid the fees within the month payment is due.
   2. The act of transmitting a large amount of information or transmitting or mediating advertisement information in a manner that may hinder the stable operation of the Service, or when such acts occur.
   3. The program running on the Member’s server may cause damage to the operation of other Member systems or causes (or risks) damage or interference of the Company’s operation of the Service.
   4. When the Member uses the Service in a manner that affects the network due to abnormal excessive traffic related to the system in operation.
   5. If the Member is expected to risk the operation of the Company's Service due to improper installation of the security update on the server.
   6. If the server used by the Member is infected with a virus or was hacked or is suspected of being infected or hacked.
   7. If the Company determines that the Member has provided false information such as a falsified membership application or misusing an identification number in order to access or use the Service for the purpose of circumventing the restrictions set by the Company for the use of the Service (e.g., free use of the Service or creating multiple Accounts to receive special price discounts, etc.)
   8. If the Member damages the Company by violating current law or through willful misconduct or gross negligence.
   9. When planning or implementing the use of the Service for the purpose of undermining national or public interests.
   10. When a Member uses the Company's Service for cryptocurrency mining.
   11. If you steal another person's Account and Password.
   12. The Member commits a breach of Section 22 and has failed to cure such breach upon receipt of a request from the Company to cure such breach within a reasonable time.
   13. When it is necessary to delete a Member’s personal information due to not using the Service for 1 year pursuant to the ‘personal information expiration period’.
   14. If you damage the reputation of another person or give another person a significant disadvantage in using the Service.
   15. If the same Member has registered multiple Accounts.
   16. If the Member interferes with the proper use of the Service, such as causing harm to the Service.
   17. If you otherwise violate relevant law or the policies set by the Company.
2. The Company may terminate the service contract without prior notice or consultation if the Member at least twice commits any of the acts set forth in paragraph 1 and despite the Company’s request to correct such behavior the Member fails to do so within 1 month of such request.
3. If the Company suspends a Member’s use of the Service due to any of the circumstances set forth in paragraph 1, the Company shall give notice of the reason for the suspension, the term of the suspension, and the method by which the Member can object to the suspension. The Company will reinstate the Service if the underlying cause for the suspension is removed or no longer in effect.
4. If the Company suspends or terminates a service contract pursuant to this Section, no Member will have any claim to any refunds for fees incurred prior to the date of such suspension or termination.
5. Upon termination of a service contract pursuant to this Section, the provision of the Service will immediately cease, and all data accumulated regarding the activities of the Member will be made private.

### Section 16 (Suspension of Termination of the Service by Members)

1. If a Member wishes to suspend or terminate a service contract, he/she must notify the Company through the procedures and methods on the homepage or the service page. Under normal circumstances, the Company will suspend or terminate the service contract according to the suspension schedule from the date of the Member’s request. However, if there remain any outstanding payments on the date the Member requested termination, all such payments must be made to proceed with the termination procedures.
2. The Member must backup all data stored on the server he/she used during the term of the service contract prior to the termination of the service contract. The Company will delete all servers and resources immediately upon the termination of the service contract and will not be restorable.
3. A Member may withdraw from his/her membership through the homepage or the service page. Upon an application to withdraw membership, the Company may seek to verify your identity before processing the withdrawal request.

### Section 17 (Information Provision and Advertisement Publication)

1. For the convenience of the Member, the Company may provide the member with various information it deems necessary for the use of the Service through email, mail, text message, application notifications, or other methods. However, the Member may access the relevant page in the homepage or the service page to unsubscribe to such notifications.
2. The Company provides the following information to Members that have consented to the receipt of such information and the Member may withdraw such consent at any time through the relevant page on the homepage or the service page.
   1. Newsletter
   2. Technical information
   3. New service notifications
3. The Company homepage or service page may include various advertisements such as banners and links, which may link to third party websites.
4. In the event you are taken to a third party website through such links mentioned in paragraph 3, please note that such pages are not part of the Company’s service and the Company does not guarantee the reliability or security of such websites, and the Company shall not be liable for any damages arising in relation to such third party websites.

## Article 3 Service Fees

### Section 18 (Service Fees)

1. The Company may charge a certain amount of fees for the use of the Service (“Service Fees”).
2. The amount in Service Fees are determined according to various factors such as the type of Service, usage time, and the amount of data processed through the Service, and the Member may select any of the following methods to pay the Service Fees. However, the details regarding the calculation method of the Service Fees, issuing of Credits, how to use the Service, and other relevant information will be posted on the service page or the bulletin board within an application or notified by email or other notification procedure.
   1. Prepayment of fixed-term fee
   2. Prepayment method for Credit recharge
   3. Monthly billing method based on monthly usage
3. The Company may provide discounts to the Service Fees and the details regarding such discounts will be posted on the service page or the bulletin board within an application or notified by email or other notification procedure.
4. If deemed necessary by the Company (e.g., if the Member expects to use a large amount of resources for the Service), the Company and the Member may reach a separate agreement regarding the Service Fees that are different from as set forth in this Section.
5. The Company may change the existing matters related to the Service Fees by giving advance notice to Members.

### Section 19 (Invoice and Payment of Service Fees)

1. Unless the Member selects a prepayment method for Service Fee payments, the Company will deliver to the Member an invoice for the Service Fees on the month following the month the Service Fees were incurred and the Member must pay such Service Fees on or prior to the payment date notified to the Member in advance.
2. Payment of the Service Fees must be made through one of the payment methods designated by the Company, such as PayPal.
3. The Company sends the invoice in advance so that the Member can receive the invoice at least 5 days before the payment due date.
4. If the Member does not pay the Service Fees to the Company by the due date, the Company may notify the Member of outstanding payments through email or other appropriate means, and any unpaid amounts will be subject to a late payment penalty (2% of the unpaid amount per month such amounts are unpaid).
5. If the Member does not pay the Service Fees by the end of next month, the Company may terminate the service contract with the Member according to the procedure and method specified in these Terms or as posted on the Company homepage or service page, upon which the Member must immediately pay any Service Fee amounts due.

### Section 20 (Service Fee Payment Obligation)

1. The Member is obligated to pay the Service Fees according to these Terms or as notified on the Company homepage or service page. However, if the Member designates another party responsible for payment of Service Fees, then such party and the Member are jointly and severally liable for such payments, in which case, the Member must provide the Company with a confirmation letter confirming that such third party is responsible for payment.
2. If a Member that selected the deferred payment method disagrees with the Service Fees charged by the Company, he/she may object by providing notice through mail or email to the Company. In such case, The Company must review the objection within 7 days of receiving the objection and notify the Member of the result. If the Company fails to comply with such period, the Company will notify the Member of the delay.

## Article 4 Rights and Responsibilities of the Parties

### Section 21 (Company Obligations)

1. The Company shall faithfully exercise its rights and perform its duties under the relevant laws and these Terms, and the Company makes efforts to provide the Service requested by the Members in a stable and continuous manner.
2. In the event of any failures that interfere with the normal operation of the Service, the Company uses best efforts to repair or restore the Service unless such is the result of natural disasters, emergencies, technical defects that are difficult to resolve, or other unavoidable circumstances. However, if a partner company’s equipment is defective or data is lost or damaged due to the willful misconduct or negligence of the partner company, the Company shall not be liable for such damage or loss unless such is caused by the Company’s willful misconduct or gross negligence.
3. If the opinion or complaint made by the Member is deemed to be justified, the Company shall fairly process such opinion or complaint according to the procedures set by the Company immediately or within a certain period. However, if prompt processing is difficult, the Member will be notified of the reason and processing schedule.
4. The Company does not access or process the Member's data related to the Service for the purposes other than these Terms of Use. However, the Company may access such data if necessary for the smooth provision of Services such as resolving defects or protection of member information.

### Section 22 (Member Obligations)

1. Members shall not commit any of the following.
   1. Abnormal system access
      1. Intentionally or negligently installing and distributing programs such as malware and viruses
      2. Reproduce, disassemble or imitate or otherwise modify the Services through reverse engineering, de-compilation, disassembly and any other similar processing
   2. Abnormal service use
      1. Using false information or another person’s information when applying for membership
      2. Acting on multiple Accounts
      3. Intentionally withdrawing/reapplying for an Account to delete adverse information in your Account
   3. Enter false or exaggerated information
      1. Enter false or exaggerated information that causes or threatens to cause interference with others’ use of the Service
   4. Violation of public order
      1. Discriminate against or promote prejudice against others based on gender, politics, religion, disability, age, social status, race, geography or occupation
      2. Slander or disparage the Company, other Members, or third parties
      3. Acts of abusive language, verbal abuse, intimidation, etc. against the Company, other Members or third parties
      4. Engaging in excessive physical exposure or indecent behavior, share information regarding prostitution, posting content that could cause sexual humiliation or offense to others, or posting information that is against public morals on the Company homepage or service page.
      5. Posting a hateful photo or contents, using language that is abusive, vulgar, or offensive, or engaging in other abnormal activity that is against social norms
   5. Infringement on the rights of others
      1. Acts that infringe or may infringe on intellectual property rights such as patents, trademarks and copyrights of the Company, other Members or third parties
      2. Infringing on the personal information of others
      3. Any action that infringes or may infringe the rights of others, including other web hacking programs, macro programs, and mirroring sites for voice phishing.
   6. Account transaction, transfer, agency, exchange, etc.
      1. Selling, transferring, leasing, or allowing or attempting to allow another person to use your Account or the contents within the Account
   7. Impersonation, identity theft
      1. Impersonating another Member, a third party, or an employee of the Company
   8. Other
      1. Unauthorized changes to information posted by the Company
      2. Use the Service for profit, sales, advertising or political activities without the Company's consent
      3. Disseminate false information for the purpose of giving property or profit to you or damage to others.
      4. Any conduct prohibited by other relevant laws, or is otherwise against social custom, or adversely affects the smooth provision of Services
2. The Company may install and operate a menu on the Company's homepage or on the service page for Members to notify or report any Member's illegal activity.
3. If a Member processes, manages, uses, or accesses a third party’s personal information during the use of the Service, the Member shall manage and protect the personal information in compliance with relevant laws and the Company shall not be liable for any results, loss, or damage relating to such actions (including without limitation the leakage of such third party’s information).
4. The Member shall possess or acquire all the rights of the server, software program, etc. operated by the Member through the Service, and shall be fully responsible for copyright issues arising therefrom.
5. If a Member distributes or sends illegal software or spam through the Service and causes damage to any other Members or third parties, the Company shall not be responsible for such damages and such Member shall indemnify the Company and make every effort to prevent the Company from being harmed by any obligations, losses, damages, or lawsuits against the Company.
6. The Member is obligated to check and abide by the provisions of these Terms, notices related to the user guide and Service, and notices from the Company.
7. Members are responsible for backing up and storing data handled while using the Service and shall be responsible for any loss caused by their neglect of data management.
8. No Member may assign, gift, provide as collateral, or transfer any rights or its status a party under these Terms or any other service contract between the Company and the Member to a third party.
9. If a minor wants to make a payment to use the Service, a legal representative must agree to the contract to proceed with the payment. Other matters concerning the transactions with minors are determined by the relevant laws and regulations.

### Section 23 (Sanctions for Member’s Breach)

1. If a Member breaches the obligations set forth in Section 22, the Company may impose any of the following sanctions after considering the importance of the relevant matter and the damages suffered by other Members, third parties, and the Company.
   1. Warning : The Company may warn the Member regarding the breach by giving written notice of the contents of and time of the breach.
   2. Use Restrictions : The Company may restrict the use of any Service, such as access to the Company's homepage or service page for the period determined by the Company, in consideration of various matters such as the degree of breach of the Member’s obligations.
   3. Permanent Suspension : The Company may permanently suspend a Member’s Account.

## Article 5 Indemnification and Disclaimers

### Section 24 (Company Indemnification)

1. The Company will indemnify Members for damages incurred by Members in using the Services that are caused by the Company’s fault.
2. The Member shall submit the documents stating the reason for the claim, the amount of the claim, and the basis of the damage calculation when the claim is made against the Company, and the Company may deduct such amounts from the Member's Service Fee payments.
3. To the extent permitted under relevant laws, the Company's liability for damages under this Section shall be limited to the total amount of Service Fees received by the Company from the Member.
4. Except in the case of willful misconduct or gross negligence of the Company, the Company shall not be liable for any damages incurred by the Member prior to entering into a service contract with the Member or in relation to the performance of the service contract.

### Section 25 (Member Indemnification)

1. Members shall indemnify and defend the Company, its affiliates, their employees, agents, partners, and license holders in the event of a dispute arising from any of the following circumstances and shall make every effort to prevent them from being harmed.
   1. If a Member breaches or violates these Terms or related laws and regulations
   2. If the Company investigates suspected breaches of the Terms or if it takes measures in the event that a breach of these Terms occurs
2. Members are responsible for compensating the Company, its employees, or representatives, for all loss, expenses, and damages (including attorneys’ fees) incurred by the Company caused by the Member’s breach of these Terms or related laws and regulations.
3. If a Member breaches any of the obligations set forth in paragraph 1 of Section 22, the Member shall pay the Company a penalty (expected damages amount) of KRW for each breach. If the damages actually incurred by the Company is greater than the penalty amount, the Company make a claim against the Member for such excess amount.

### Section 26 (Disclaimers)

1. The Company shall not be liable under any of the following circumstances.
   1. If it is impossible to provide Services due to war, attack, natural disasters, national emergencies, technical defects that are difficult to resolve, or other force majeure
   2. In case of suspension of service, disability of service, or termination of service contract due to the Member's fault
   3. Where the telecommunications service provider suspends or fails to provide normal telecommunications services
   4. When the Service is suspended or a failure occurs due to unavoidable reasons such as repair, replacement, regular inspection, construction, etc.
   5. In case of problems caused by the Member’s computer environment or the network environment without the Company’s willful misconduct or gross negligence
   6. If the Service is suspended or a failure occurs due to a partner company’s circumstances such as equipment failure
   7. In case of dispute between Members or between a Member and a third party within the Service
   8. There is no intentional or gross negligence of the Company in relation to the free Service provided by the Company
   9. There is no intentional or gross negligence of the Company in relation to the free Service provided by another company
   10. Despite the normal provision of the Service, the Member fails to achieve or loses his/her expected profits or results or suffers a loss due to his/her own choices.
   11. In case of damage caused by the Member's computer error or caused by the provision of inaccurate information or email address, etc.
   12. Inability to provide services in accordance with applicable laws, government policies, etc.
   13. There is no intentional or gross negligence of the Company regarding the contents of information, materials, facts, reliability, accuracy, etc. posted or transmitted by the Member or a third party on the Service or on the Company homepage.
   14. Except in the case of the Company’s willful misconduct or gross negligence, the Member suffers loss or damage when the member uploads data on the Cloud Service without separately backing up or storing such data.
2. Members post information and opinions on the Company’s homepage or service pages according to their rights and responsibilities, and the Company does not verify the truth, accuracy or reliability of the facts, information and opinions displayed by Members or third parties while providing the Service. Accordingly, the Company shall not be liable for any loss or damage caused by the Member’s reliance on the above information and opinions.
3. If Company incurs damages or is subject to criminal penalties or sanctions from investigative agencies or administrative agencies due to a Member’s illegal activity or breach of these Terms, the Member shall indemnify the Company for any and all losses (including without limitation compensatory damages, lawsuit expenses, and attorneys’ fees).

## Article 6 Miscellaneous

### Section 27 (Governing Law and Jurisdiction)

1. These Terms and the service contracts shall be governed by the laws of Korea regardless of the place of residence of the Member.
2. In the event of any dispute between the Company and a Member regarding the formation of the service contract or the provision of the Service, the Company and the Member shall take all necessary efforts to resolve such dispute amicably. If a lawsuit is filed regarding such a dispute, the court that has jurisdiction over the Company’s location shall have exclusive jurisdiction over such lawsuit.
3. Notwithstanding paragraph 1, any judgments made by the court pursuant to paragraph 2 may be executed by a court having jurisdiction over the location of the Company or the Member.

### Section 28 (Severability)

If any provision of these Terms is deemed invalid or unenforceable by a court or competent jurisdiction, the other provisions shall remain in full force and effect.

### Section 29 (Waiver)

Any failure by the Company to exercise its rights or take any action in connection with the breach of these Terms by a Member shall not be deemed as a waiver of such rights with respect to the same or similar conduct of the Member.

## Addendum

These Terms were made on AUG. 15th, 2019 and shall be effective as of AUG. 16th, 2019.